# eslint-config-airbnb-typescript

This package provides Airbnb's JS .eslintrc as an extensible shared config.

## Usage

1. Install correct version of each package, which are listed by the command:

```sh
npm info "eslint-config-typescript-airbnb@latest" peerDependencies
```

if you using __npm 5+__, use this shortcut

```sh
npx install-peerdeps --dev eslint-config-airbnb-base-typescript
```

This will work with __yarn__, npx will detect that you are using yarn and install dependencies via yarn.

2. Add `"extends": "typescript-airbnb"` to your .eslintrc.

## Linting your project

Edit `package.json` file and following scripts

### yarn

```json
  "lint": "eslint --ext .ts,.tsx 'src/**/*.ts?'"
  "lint:fix": "yarn lint --fix",
```

### npm

```json
  "lint": "eslint --ext .ts,.tsx 'src/**/*.ts?'"
  "lint:fix": "npm run lint -- --fix",
```

## Editor setup

### Webstorm

- Disable `tslint`
- Enable `eslint`
- Under `help` > `find actions`
- Add `ts,tsx` to `eslint.additional.file.extensions`

[Eslint for typescript[BUG]](https://intellij-support.jetbrains.com/hc/en-us/community/posts/360003326300-ESLint-errors-not-shown-in-editor-window)

> Webstorm cannot have [eslint fix on save](https://intellij-support.jetbrains.com/hc/en-us/community/posts/115000221130-Eslint-autofix-on-save-for-webstorm)

### VS Code

You should uninstall `tslint` and `Prettier` from extensions.

- Install [eslint](https://marketplace.visualstudio.com/items?itemName=dbaeumer.vscode-eslint) extension
- Under `File` > `Preferences` > `Settings`
- Open `Edit in settings.json`
- Add following lines

```json
"eslint.validate": [
  "javascript",
  "javascriptreact",
  {
    "language": "typescript",
    "autoFix": true
  },
  {
    "language": "typescriptreact",
    "autoFix": true
  }
]
```

- Optionally you can enable/disable `Eslint: Auto Fix On Save`
  - This will enable more code style functionality than basic prettier

## Credits

This config was inspired by [eslint-config-react-app](https://github.com/facebook/create-react-app/tree/master/packages/eslint-config-react-app) and [eslint-config-airbnb](https://github.com/airbnb/javascript/blob/master/packages/eslint-config-airbnb).
